=== modified file 'assess_recovery.py'
--- assess_recovery.py	2016-12-05 15:50:23 +0000
+++ assess_recovery.py	2016-12-05 16:26:19 +0000
@@ -148,7 +148,7 @@
     return deleted_machines
 
 
-def restore_missing_state_server(client, controller_client, backup_file,
+def restore_missing_state_server(bs_manager, controller_client, backup_file,
                                  check_controller=True):
     """juju-restore creates a replacement state-server for the services."""
     log.info("Starting restore.")
@@ -161,12 +161,13 @@
         raise LoggedException(e)
     if check_controller:
         controller_client.wait_for_started(600)
-    show_controller(client)
-    client.set_config('dummy-source', {'token': 'Two'})
-    client.wait_for_started()
-    client.wait_for_workloads()
-    check_token(client, 'Two')
-    log.info("%s restored", client.env.environment)
+    show_controller(bs_manager.client)
+    bs_manager.has_controller = True
+    bs_manager.client.set_config('dummy-source', {'token': 'Two'})
+    bs_manager.client.wait_for_started()
+    bs_manager.client.wait_for_workloads()
+    check_token(bs_manager.client, 'Two')
+    log.info("%s restored", bs_manager.client.env.environment)
     log.info("PASS")
 
 
@@ -222,8 +223,9 @@
         assess_ha_recovery(bs_manager, client)
     else:
         check_controller = strategy != 'ha-backup'
-        restore_missing_state_server(client, controller_client, backup_file,
-                                     check_controller=check_controller)
+        restore_missing_state_server(
+            bs_manager, controller_client, backup_file,
+            check_controller=check_controller)
     log.info("Test complete.")
 
 

=== modified file 'tests/test_assess_recovery.py'
--- tests/test_assess_recovery.py	2016-12-05 15:50:23 +0000
+++ tests/test_assess_recovery.py	2016-12-05 16:26:19 +0000
@@ -230,6 +230,11 @@
         self.assertIsFalse(bs_manager.has_controller)
 
 
+def make_bs_manager(client):
+    return BootstrapManager('foo', client, client, None, [], None, None, None,
+                            None, None, None, None, None)
+
+
 @patch('assess_recovery.wait_for_state_server_to_shutdown', autospec=True)
 @patch('assess_recovery.terminate_instances', autospec=True)
 class TestDeleteControllerMembers(FakeHomeTestCase):
@@ -334,9 +339,7 @@
 
     def test_leader_only_has_controller(self, ti_mock, wsss_mock):
         client = fake_juju_client()
-        bs_manager = BootstrapManager('foo', client, client, None, [], None,
-                                      None, None, None, None, None, None,
-                                      None)
+        bs_manager = make_bs_manager(client)
         client.bootstrap()
         bs_manager.has_controller = True
         delete_controller_members(
@@ -345,9 +348,7 @@
 
     def test_no_leader_only_has_controller(self, ti_mock, wsss_mock):
         client = fake_juju_client()
-        bs_manager = BootstrapManager('foo', client, client, None, [], None,
-                                      None, None, None, None, None, None,
-                                      None)
+        bs_manager = make_bs_manager(client)
         client.bootstrap()
         bs_manager.has_controller = True
         delete_controller_members(
@@ -365,7 +366,7 @@
                    autospec=True, return_value='Token: Two'):
             with patch('assess_recovery.show_controller', autospec=True):
                 restore_missing_state_server(
-                    client, controller_client, 'backup_file',
+                    make_bs_manager(client), controller_client, 'backup_file',
                     check_controller=True)
         controller_client.restore_backup.assert_called_once_with('backup_file')
         controller_client.wait_for_started.assert_called_once_with(600)
@@ -382,10 +383,22 @@
                    autospec=True, return_value='Token: Two'):
             with patch('assess_recovery.show_controller', autospec=True):
                 restore_missing_state_server(
-                    client, controller_client, 'backup_file',
+                    make_bs_manager(client), controller_client, 'backup_file',
                     check_controller=False)
         self.assertEqual(0, controller_client.wait_for_started.call_count)
 
+    def test_set_has_controller(self):
+        client = fake_juju_client()
+        client.bootstrap()
+        client.deploy('dummy-sink')
+        controller_client = client.get_controller_client()
+        bs_manager = make_bs_manager(client)
+        with patch('assess_recovery.get_token_from_status',
+                   return_value='Two'):
+            restore_missing_state_server(bs_manager, controller_client,
+                                         'backup_file')
+        self.assertIs(True, bs_manager.has_controller)
+
 
 class TestCheckToken(TestCase):
 

